package com.chelvc.cloud.admin.controller;

import javax.validation.constraints.NotNull;

import com.chelvc.cloud.vehicle.client.DynamicContentClient;
import com.chelvc.cloud.vehicle.client.dto.DynamicContentDTO;
import com.chelvc.cloud.vehicle.client.param.EditShieldDynamicParam;
import com.chelvc.cloud.vehicle.client.param.ExamineDynamicParam;
import com.chelvc.cloud.vehicle.client.param.QueryAdminDynamicParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 动态信息
 *
 * @author igl
 * @date 2023-02-25
 */
@Validated
@RestController
@RequestMapping("/content")
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class DynamicContentController {
    private final DynamicContentClient dynamicContentClient;

    /**
     * 查询列表
     *
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @GetMapping("/list")
    public Pagination<DynamicContentDTO> list(QueryAdminDynamicParam param) {
        return this.dynamicContentClient.queryAdminPageList(param);
    }

    /**
     * 屏蔽某条动态
     *
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @PutMapping("/shield/update")
    public void shieldById(@Validated @RequestBody EditShieldDynamicParam param) {
        this.dynamicContentClient.shieldById(param.getId(), param.getPlatformStatus());
    }

    /**
     * 屏蔽某个用户所有动态
     *
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @PutMapping("/shield/update-all")
    public void shieldByUserId(@Validated @RequestBody EditShieldDynamicParam param) {
        dynamicContentClient.shieldByUserId(param.getId(), param.getPlatformStatus());
    }

    /**
     * 动态手动审核
     *
     * @param param
     * @author igl
     * @date 2023/8/17 17:25
     */
    @PutMapping("/examine")
    public void examine(@Validated @RequestBody ExamineDynamicParam param) {
        dynamicContentClient.examine(param.getId(), param.getExamine());
    }

    /**
     * 获取动态详情
     *
     * @param id 主键
     * @author igl
     * @date 2023/8/9 17:25
     */
    @GetMapping("/detail")
    public DynamicContentDTO getInfo(@NotNull(message = "主键不能为空") @PathVariable Long id) {
        return dynamicContentClient.queryById(id, null);
    }
}
