package com.chelvc.cloud.admin.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.MerchantAuthClient;
import com.chelvc.cloud.vehicle.client.dto.MerchantAuthDTO;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthModifyParam;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthPagingParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商家认证接口
 *
 * @author liude
 * @date 2023/12/13
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MerchantAuthController {
    private final MerchantAuthClient merchantAuthClient;

    /**
     * 查询商家商家认证分页
     *
     * @param param 查询参数
     * @return 商家商家认证分页信息
     */
    @GetMapping("/merchantAuth/paging")
    public Pagination<MerchantAuthDTO> getMerchantAuthPaging(@Valid MerchantAuthPagingParam param) {
        return this.merchantAuthClient.getMerchantAuthPaging(param);
    }

    /**
     * 商家认证审核
     *
     * @param id    商家商家认证主键
     * @param state 0-拒绝 1-通过
     */
    @GetMapping("/certificationAudit/{id}")
    public void certificationAudit(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                   String state, String message) {
        this.merchantAuthClient.certificationAudit(id, state, message);
    }


    /**
     * 新增商家认证
     *
     * @param param 新增参数
     * @return 商家商家认证主键
     */
    @PostMapping("/merchantAuth")
    public Long addMerchantAuth(@RequestBody @Valid MerchantAuthModifyParam param) {
        return this.merchantAuthClient.addMerchantAuth(param);
    }

    /**
     * 修改商家商家认证
     *
     * @param id    商家商家认证主键
     * @param param 修改参数
     */
    @PutMapping("/merchantAuth/{id}")
    public void updateMerchantAuth(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                   @RequestBody @Valid MerchantAuthModifyParam param) {
        this.merchantAuthClient.updateMerchantAuth(id, param);
    }

    /**
     * 查询商家认证
     */
    @PostMapping("/merchantAuth/queryById")
    public MerchantAuthDTO queryById() {
        return this.merchantAuthClient.queryById();
    }
}
